# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='base_gcmessages.proto',
  package='dota',
  syntax='proto2',
  serialized_options=_b('H\001\220\001\000'),
  serialized_pb=_b('\n\x15\x62\x61se_gcmessages.proto\x12\x04\x64ota\x1a\x13steammessages.proto\"\x9a\x01\n\x1d\x43GCStorePurchaseInit_LineItem\x12\x13\n\x0bitem_def_id\x18\x01 \x01(\r\x12\x10\n\x08quantity\x18\x02 \x01(\r\x12\x1e\n\x16\x63ost_in_local_currency\x18\x03 \x01(\r\x12\x15\n\rpurchase_type\x18\x04 \x01(\r\x12\x1b\n\x13source_reference_id\x18\x05 \x01(\x04\"\x87\x01\n\x17\x43MsgGCStorePurchaseInit\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x03 \x01(\x05\x12\x37\n\nline_items\x18\x04 \x03(\x0b\x32#.dota.CGCStorePurchaseInit_LineItem\"A\n\x1f\x43MsgGCStorePurchaseInitResponse\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06txn_id\x18\x02 \x01(\x04\"&\n\x13\x43MsgSystemBroadcast\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9e\x01\n\x12\x43MsgClientPingData\x12\x17\n\x0brelay_codes\x18\x04 \x03(\x07\x42\x02\x10\x01\x12\x17\n\x0brelay_pings\x18\x05 \x03(\rB\x02\x10\x01\x12\x18\n\x0cregion_codes\x18\x08 \x03(\rB\x02\x10\x01\x12\x18\n\x0cregion_pings\x18\t \x03(\rB\x02\x10\x01\x12\"\n\x1aregion_ping_failed_bitmask\x18\n \x01(\r\"\x8d\x01\n\x11\x43MsgInviteToParty\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x0f\n\x07team_id\x18\x03 \x01(\r\x12\x10\n\x08\x61s_coach\x18\x04 \x01(\x08\x12+\n\tping_data\x18\x05 \x01(\x0b\x32\x18.dota.CMsgClientPingData\"=\n\x11\x43MsgInviteToLobby\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\"Q\n\x15\x43MsgInvitationCreated\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\x10\n\x08steam_id\x18\x02 \x01(\x06\x12\x14\n\x0cuser_offline\x18\x03 \x01(\x08\"\x80\x01\n\x17\x43MsgPartyInviteResponse\x12\x10\n\x08party_id\x18\x01 \x01(\x04\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12+\n\tping_data\x18\x08 \x01(\x0b\x32\x18.dota.CMsgClientPingData\"\x8b\x01\n\x17\x43MsgLobbyInviteResponse\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12\x17\n\x0f\x63ustom_game_crc\x18\x06 \x01(\x06\x12\x1d\n\x15\x63ustom_game_timestamp\x18\x07 \x01(\x07\"%\n\x11\x43MsgKickFromParty\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"\x10\n\x0e\x43MsgLeaveParty\"\xa7\x01\n\x1b\x43MsgCustomGameInstallStatus\x12R\n\x06status\x18\x01 \x01(\x0e\x32\x1e.dota.ECustomGameInstallStatus:\"k_ECustomGameInstallStatus_Unknown\x12\x0f\n\x07message\x18\x02 \x01(\t\x12#\n\x1blatest_timestamp_from_steam\x18\x03 \x01(\x07\"\\\n\x13\x43MsgServerAvailable\x12\x45\n\x1a\x63ustom_game_install_status\x18\x01 \x01(\x0b\x32!.dota.CMsgCustomGameInstallStatus\"*\n\x16\x43MsgLANServerAvailable\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\"\xaa\x02\n\x18\x43SOEconGameAccountClient\x12$\n\x19\x61\x64\x64itional_backpack_slots\x18\x01 \x01(\r:\x01\x30\x12\x1c\n\rtrial_account\x18\x02 \x01(\x08:\x05\x66\x61lse\x12&\n\x18\x65ligible_for_online_play\x18\x03 \x01(\x08:\x04true\x12*\n\"need_to_choose_most_helpful_friend\x18\x04 \x01(\x08\x12\x17\n\x0fin_coaches_list\x18\x05 \x01(\x08\x12\x1c\n\x14trade_ban_expiration\x18\x06 \x01(\x07\x12\x1b\n\x13\x64uel_ban_expiration\x18\x07 \x01(\x07\x12\"\n\x13made_first_purchase\x18\t \x01(\x08:\x05\x66\x61lse\"r\n\x18\x43SOItemCriteriaCondition\x12\n\n\x02op\x18\x01 \x01(\x05\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x13\n\x0b\x66loat_value\x18\x04 \x01(\x02\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\x88\x02\n\x0f\x43SOItemCriteria\x12\x12\n\nitem_level\x18\x01 \x01(\r\x12\x14\n\x0citem_quality\x18\x02 \x01(\x05\x12\x16\n\x0eitem_level_set\x18\x03 \x01(\x08\x12\x18\n\x10item_quality_set\x18\x04 \x01(\x08\x12\x19\n\x11initial_inventory\x18\x05 \x01(\r\x12\x18\n\x10initial_quantity\x18\x06 \x01(\r\x12\x1b\n\x13ignore_enabled_flag\x18\x08 \x01(\x08\x12\x32\n\nconditions\x18\t \x03(\x0b\x32\x1e.dota.CSOItemCriteriaCondition\x12\x13\n\x0brecent_only\x18\n \x01(\x08\"\xdf\x03\n\rCSOItemRecipe\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03n_a\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_inputs\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65sc_outputs\x18\x05 \x01(\t\x12\x0c\n\x04\x64i_a\x18\x06 \x01(\t\x12\x0c\n\x04\x64i_b\x18\x07 \x01(\t\x12\x0c\n\x04\x64i_c\x18\x08 \x01(\t\x12\x0c\n\x04\x64o_a\x18\t \x01(\t\x12\x0c\n\x04\x64o_b\x18\n \x01(\t\x12\x0c\n\x04\x64o_c\x18\x0b \x01(\t\x12\x1f\n\x17requires_all_same_class\x18\x0c \x01(\x08\x12\x1e\n\x16requires_all_same_slot\x18\r \x01(\x08\x12\x1e\n\x16\x63lass_usage_for_output\x18\x0e \x01(\x05\x12\x1d\n\x15slot_usage_for_output\x18\x0f \x01(\x05\x12\x16\n\x0eset_for_output\x18\x10 \x01(\x05\x12\x33\n\x14input_items_criteria\x18\x14 \x03(\x0b\x32\x15.dota.CSOItemCriteria\x12\x34\n\x15output_items_criteria\x18\x15 \x03(\x0b\x32\x15.dota.CSOItemCriteria\x12\x1e\n\x16input_item_dupe_counts\x18\x16 \x03(\r\"J\n\x14\x43MsgApplyStrangePart\x12\x1c\n\x14strange_part_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\"K\n\x17\x43MsgApplyPennantUpgrade\x12\x17\n\x0fupgrade_item_id\x18\x01 \x01(\x04\x12\x17\n\x0fpennant_item_id\x18\x02 \x01(\x04\"C\n\x13\x43MsgApplyEggEssence\x12\x17\n\x0f\x65ssence_item_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x65gg_item_id\x18\x02 \x01(\x04\"M\n\x14\x43SOEconItemAttribute\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x13\n\x0bvalue_bytes\x18\x03 \x01(\x0c\":\n\x13\x43SOEconItemEquipped\x12\x11\n\tnew_class\x18\x01 \x01(\r\x12\x10\n\x08new_slot\x18\x02 \x01(\r\"\xe9\x02\n\x0b\x43SOEconItem\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x11\n\tinventory\x18\x03 \x01(\r\x12\x11\n\tdef_index\x18\x04 \x01(\r\x12\x13\n\x08quantity\x18\x05 \x01(\r:\x01\x31\x12\x10\n\x05level\x18\x06 \x01(\r:\x01\x31\x12\x12\n\x07quality\x18\x07 \x01(\r:\x01\x34\x12\x10\n\x05\x66lags\x18\x08 \x01(\r:\x01\x30\x12\x11\n\x06origin\x18\t \x01(\r:\x01\x30\x12-\n\tattribute\x18\x0c \x03(\x0b\x32\x1a.dota.CSOEconItemAttribute\x12(\n\rinterior_item\x18\r \x01(\x0b\x32\x11.dota.CSOEconItem\x12\x10\n\x05style\x18\x0f \x01(\r:\x01\x30\x12\x16\n\x0boriginal_id\x18\x10 \x01(\x04:\x01\x30\x12\x31\n\x0e\x65quipped_state\x18\x12 \x03(\x0b\x32\x19.dota.CSOEconItemEquipped\"\"\n\rCMsgSortItems\x12\x11\n\tsort_type\x18\x01 \x01(\r\"^\n\x10\x43SOEconClaimCode\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tcode_type\x18\x02 \x01(\r\x12\x15\n\rtime_acquired\x18\x03 \x01(\r\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\"_\n\x14\x43MsgUpdateItemSchema\x12\x12\n\nitems_game\x18\x01 \x01(\x0c\x12\x1b\n\x13item_schema_version\x18\x02 \x01(\x07\x12\x16\n\x0eitems_game_url\x18\x03 \x01(\t\"!\n\x0b\x43MsgGCError\x12\x12\n\nerror_text\x18\x01 \x01(\t\"\x1d\n\x1b\x43MsgRequestInventoryRefresh\".\n\x0f\x43MsgConVarValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\">\n\x14\x43MsgReplicateConVars\x12&\n\x07\x63onvars\x18\x01 \x03(\x0b\x32\x15.dota.CMsgConVarValue\"\x81\x01\n\x14\x43MsgItemAcknowledged\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tinventory\x18\x02 \x01(\r\x12\x11\n\tdef_index\x18\x03 \x01(\r\x12\x0f\n\x07quality\x18\x04 \x01(\r\x12\x0e\n\x06rarity\x18\x05 \x01(\r\x12\x0e\n\x06origin\x18\x06 \x01(\r\"\x8a\x01\n\x14\x43MsgSetItemPositions\x12?\n\x0eitem_positions\x18\x01 \x03(\x0b\x32\'.dota.CMsgSetItemPositions.ItemPosition\x1a\x31\n\x0cItemPosition\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x10\n\x08position\x18\x02 \x01(\r\"f\n\x1a\x43MsgGCNameItemNotification\x12\x16\n\x0eplayer_steamid\x18\x01 \x01(\x06\x12\x16\n\x0eitem_def_index\x18\x02 \x01(\r\x12\x18\n\x10item_name_custom\x18\x03 \x01(\t\"\xb6\x01\n\x1f\x43MsgGCClientDisplayNotification\x12+\n#notification_title_localization_key\x18\x01 \x01(\t\x12*\n\"notification_body_localization_key\x18\x02 \x01(\t\x12\x1b\n\x13\x62ody_substring_keys\x18\x03 \x03(\t\x12\x1d\n\x15\x62ody_substring_values\x18\x04 \x03(\t\"1\n\x17\x43MsgGCShowItemsPickedUp\x12\x16\n\x0eplayer_steamid\x18\x01 \x01(\x06\"|\n CMsgGCIncrementKillCountResponse\x12\x1f\n\x11killer_account_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x11\n\tnum_kills\x18\x02 \x01(\r\x12\x10\n\x08item_def\x18\x03 \x01(\r\x12\x12\n\nlevel_type\x18\x04 \x01(\r\"\xcd\x01\n\x18\x43SOEconItemDropRateBonus\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x17\n\x0f\x65xpiration_date\x18\x02 \x01(\x07\x12\x13\n\x05\x62onus\x18\x03 \x01(\x02\x42\x04\x80\x97\"\x01\x12\x13\n\x0b\x62onus_count\x18\x04 \x01(\r\x12\x0f\n\x07item_id\x18\x05 \x01(\x04\x12\x11\n\tdef_index\x18\x06 \x01(\r\x12\x14\n\x0cseconds_left\x18\x07 \x01(\r\x12\x1a\n\x0c\x62ooster_type\x18\x08 \x01(\rB\x04\x80\x97\"\x01\"w\n\x19\x43SOEconItemLeagueViewPass\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x17\n\tleague_id\x18\x02 \x01(\rB\x04\x80\x97\"\x01\x12\x11\n\titemindex\x18\x04 \x01(\r\x12\x14\n\x0cgrant_reason\x18\x05 \x01(\r\"O\n\x16\x43SOEconItemEventTicket\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\"\xca\x01\n\x1d\x43SOEconItemTournamentPassport\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\x12\x1d\n\x15original_purchaser_id\x18\x04 \x01(\r\x12\x18\n\x10passports_bought\x18\x05 \x01(\r\x12\x0f\n\x07version\x18\x06 \x01(\r\x12\x11\n\tdef_index\x18\x07 \x01(\r\x12\x14\n\x0creward_flags\x18\x08 \x01(\r\"+\n\x19\x43MsgGCStorePurchaseCancel\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\"3\n!CMsgGCStorePurchaseCancelResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1b\x43MsgGCStorePurchaseFinalize\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\"G\n#CMsgGCStorePurchaseFinalizeResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x10\n\x08item_ids\x18\x02 \x03(\x04\"3\n\x1f\x43MsgGCToGCBannedWordListUpdated\x12\x10\n\x08group_id\x18\x01 \x01(\r\"?\n\x17\x43MsgGCToGCDirtySDOCache\x12\x10\n\x08sdo_type\x18\x01 \x01(\r\x12\x12\n\nkey_uint64\x18\x02 \x01(\x04\"G\n\x1f\x43MsgGCToGCDirtyMultipleSDOCache\x12\x10\n\x08sdo_type\x18\x01 \x01(\r\x12\x12\n\nkey_uint64\x18\x02 \x03(\x04\"H\n\x1f\x43MsgGCToGCApplyLocalizationDiff\x12\x10\n\x08language\x18\x01 \x01(\r\x12\x13\n\x0bpacked_diff\x18\x02 \x01(\t\":\n\'CMsgGCToGCApplyLocalizationDiffResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"H\n\x11\x43MsgGCCollectItem\x12\x1a\n\x12\x63ollection_item_id\x18\x01 \x01(\x04\x12\x17\n\x0fsubject_item_id\x18\x02 \x01(\x04\"\x14\n\x12\x43MsgSDONoMemcached\"/\n\x1b\x43MsgGCToGCUpdateSQLKeyValue\x12\x10\n\x08key_name\x18\x01 \x01(\t\"4\n\x1a\x43MsgGCServerVersionUpdated\x12\x16\n\x0eserver_version\x18\x01 \x01(\r\"4\n\x1a\x43MsgGCClientVersionUpdated\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\" \n\x1e\x43MsgGCToGCWebAPIAccountChanged\"G\n\x13\x43MsgRecipeComponent\x12\x17\n\x0fsubject_item_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x61ttribute_index\x18\x02 \x01(\x04\"t\n!CMsgFulfillDynamicRecipeComponent\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x39\n\x16\x63onsumption_components\x18\x02 \x03(\x0b\x32\x19.dota.CMsgRecipeComponent\"6\n\x1d\x43MsgGCClientMarketDataRequest\x12\x15\n\ruser_currency\x18\x01 \x01(\r\"\x88\x01\n\x1b\x43MsgGCClientMarketDataEntry\x12\x16\n\x0eitem_def_index\x18\x01 \x01(\r\x12\x14\n\x0citem_quality\x18\x02 \x01(\r\x12\x1a\n\x12item_sell_listings\x18\x03 \x01(\r\x12\x1f\n\x17price_in_local_currency\x18\x04 \x01(\r\"L\n\x16\x43MsgGCClientMarketData\x12\x32\n\x07\x65ntries\x18\x01 \x03(\x0b\x32!.dota.CMsgGCClientMarketDataEntry\"\\\n\x0f\x43MsgExtractGems\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\x12\x1d\n\x0eitem_socket_id\x18\x03 \x01(\r:\x05\x36\x35\x35\x33\x35\"\xd9\x02\n\x17\x43MsgExtractGemsResponse\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12U\n\x08response\x18\x02 \x01(\x0e\x32*.dota.CMsgExtractGemsResponse.EExtractGems:\x17k_ExtractGems_Succeeded\"\xd5\x01\n\x0c\x45\x45xtractGems\x12\x1b\n\x17k_ExtractGems_Succeeded\x10\x00\x12&\n\"k_ExtractGems_Failed_ToolIsInvalid\x10\x01\x12&\n\"k_ExtractGems_Failed_ItemIsInvalid\x10\x02\x12,\n(k_ExtractGems_Failed_ToolCannotRemoveGem\x10\x03\x12*\n&k_ExtractGems_Failed_FailedToRemoveGem\x10\x04\"L\n\rCMsgAddSocket\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\x12\x0f\n\x07unusual\x18\x03 \x01(\x08\"\xbe\x02\n\x15\x43MsgAddSocketResponse\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x1c\n\x14updated_socket_index\x18\x02 \x03(\r\x12O\n\x08response\x18\x03 \x01(\x0e\x32&.dota.CMsgAddSocketResponse.EAddSocket:\x15k_AddSocket_Succeeded\"\xa4\x01\n\nEAddSocket\x12\x19\n\x15k_AddSocket_Succeeded\x10\x00\x12$\n k_AddSocket_Failed_ToolIsInvalid\x10\x01\x12+\n\'k_AddSocket_Failed_ItemCannotBeSocketed\x10\x02\x12(\n$k_AddSocket_Failed_FailedToAddSocket\x10\x03\"D\n\x17\x43MsgAddItemToSocketData\x12\x13\n\x0bgem_item_id\x18\x01 \x01(\x04\x12\x14\n\x0csocket_index\x18\x02 \x01(\r\"b\n\x13\x43MsgAddItemToSocket\x12\x14\n\x0citem_item_id\x18\x01 \x01(\x04\x12\x35\n\x0egems_to_socket\x18\x02 \x03(\x0b\x32\x1d.dota.CMsgAddItemToSocketData\"\xe4\x03\n\x1b\x43MsgAddItemToSocketResponse\x12\x14\n\x0citem_item_id\x18\x01 \x01(\x04\x12\x1c\n\x14updated_socket_index\x18\x02 \x03(\r\x12O\n\x08response\x18\x03 \x01(\x0e\x32).dota.CMsgAddItemToSocketResponse.EAddGem:\x12k_AddGem_Succeeded\"\xbf\x02\n\x07\x45\x41\x64\x64Gem\x12\x16\n\x12k_AddGem_Succeeded\x10\x00\x12 \n\x1ck_AddGem_Failed_GemIsInvalid\x10\x01\x12!\n\x1dk_AddGem_Failed_ItemIsInvalid\x10\x02\x12\"\n\x1ek_AddGem_Failed_FailedToAddGem\x10\x03\x12+\n\'k_AddGem_Failed_InvalidGemTypeForSocket\x10\x04\x12)\n%k_AddGem_Failed_InvalidGemTypeForHero\x10\x05\x12)\n%k_AddGem_Failed_InvalidGemTypeForSlot\x10\x06\x12\x30\n,k_AddGem_Failed_SocketContainsUnremovableGem\x10\x07\"F\n\x18\x43MsgResetStrangeGemCount\x12\x14\n\x0citem_item_id\x18\x01 \x01(\x04\x12\x14\n\x0csocket_index\x18\x02 \x01(\r\"\xc3\x02\n CMsgResetStrangeGemCountResponse\x12X\n\x08response\x18\x01 \x01(\x0e\x32\x30.dota.CMsgResetStrangeGemCountResponse.EResetGem:\x14k_ResetGem_Succeeded\"\xc4\x01\n\tEResetGem\x12\x18\n\x14k_ResetGem_Succeeded\x10\x00\x12&\n\"k_ResetGem_Failed_FailedToResetGem\x10\x01\x12#\n\x1fk_ResetGem_Failed_ItemIsInvalid\x10\x02\x12%\n!k_ResetGem_Failed_InvalidSocketId\x10\x03\x12)\n%k_ResetGem_Failed_SocketCannotBeReset\x10\x04\"[\n\x1d\x43MsgGCToClientPollFileRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x0f\n\x07poll_id\x18\x03 \x01(\r\"D\n\x1e\x43MsgGCToClientPollFileResponse\x12\x0f\n\x07poll_id\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\">\n\x19\x43MsgGCToGCPerformManualOp\x12\r\n\x05op_id\x18\x01 \x01(\x04\x12\x12\n\ngroup_code\x18\x02 \x01(\r\"H\n\"CMsgGCToGCPerformManualOpCompleted\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x11\n\tsource_gc\x18\x02 \x01(\r\"&\n$CMsgGCToGCReloadServerRegionSettings*\x8f\x05\n\nEGCBaseMsg\x12\x1a\n\x15k_EMsgGCSystemMessage\x10\xa1\x1f\x12\x1d\n\x18k_EMsgGCReplicateConVars\x10\xa2\x1f\x12\x1a\n\x15k_EMsgGCConVarUpdated\x10\xa3\x1f\x12\x1a\n\x15k_EMsgGCInviteToParty\x10\x95#\x12\x1e\n\x19k_EMsgGCInvitationCreated\x10\x96#\x12 \n\x1bk_EMsgGCPartyInviteResponse\x10\x97#\x12\x1a\n\x15k_EMsgGCKickFromParty\x10\x98#\x12\x17\n\x12k_EMsgGCLeaveParty\x10\x99#\x12\x1c\n\x17k_EMsgGCServerAvailable\x10\x9a#\x12\"\n\x1dk_EMsgGCClientConnectToServer\x10\x9b#\x12\x1b\n\x16k_EMsgGCGameServerInfo\x10\x9c#\x12\x12\n\rk_EMsgGCError\x10\x9d#\x12\x1f\n\x1ak_EMsgGCLANServerAvailable\x10\x9f#\x12\x1a\n\x15k_EMsgGCInviteToLobby\x10\xa0#\x12 \n\x1bk_EMsgGCLobbyInviteResponse\x10\xa1#\x12$\n\x1fk_EMsgGCToClientPollFileRequest\x10\xa2#\x12%\n k_EMsgGCToClientPollFileResponse\x10\xa3#\x12 \n\x1bk_EMsgGCToGCPerformManualOp\x10\xa4#\x12)\n$k_EMsgGCToGCPerformManualOpCompleted\x10\xa5#\x12+\n&k_EMsgGCToGCReloadServerRegionSettings\x10\xa6#*Y\n\x17\x45GCBaseProtoObjectTypes\x12\x1e\n\x19k_EProtoObjectPartyInvite\x10\xe9\x07\x12\x1e\n\x19k_EProtoObjectLobbyInvite\x10\xea\x07*\xe8\x03\n\x18\x45\x43ustomGameInstallStatus\x12&\n\"k_ECustomGameInstallStatus_Unknown\x10\x00\x12$\n k_ECustomGameInstallStatus_Ready\x10\x01\x12#\n\x1fk_ECustomGameInstallStatus_Busy\x10\x02\x12,\n(k_ECustomGameInstallStatus_FailedGeneric\x10\x65\x12\x32\n.k_ECustomGameInstallStatus_FailedInternalError\x10\x66\x12\x37\n3k_ECustomGameInstallStatus_RequestedTimestampTooOld\x10g\x12\x37\n3k_ECustomGameInstallStatus_RequestedTimestampTooNew\x10h\x12*\n&k_ECustomGameInstallStatus_CRCMismatch\x10i\x12*\n&k_ECustomGameInstallStatus_FailedSteam\x10j\x12-\n)k_ECustomGameInstallStatus_FailedCanceled\x10kB\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,])

_EGCBASEMSG = _descriptor.EnumDescriptor(
  name='EGCBaseMsg',
  full_name='dota.EGCBaseMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSystemMessage', index=0, number=4001,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReplicateConVars', index=1, number=4002,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConVarUpdated', index=2, number=4003,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInviteToParty', index=3, number=4501,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInvitationCreated', index=4, number=4502,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartyInviteResponse', index=5, number=4503,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCKickFromParty', index=6, number=4504,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaveParty', index=7, number=4505,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerAvailable', index=8, number=4506,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientConnectToServer', index=9, number=4507,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameServerInfo', index=10, number=4508,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCError', index=11, number=4509,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLANServerAvailable', index=12, number=4511,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInviteToLobby', index=13, number=4512,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLobbyInviteResponse', index=14, number=4513,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPollFileRequest', index=15, number=4514,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToClientPollFileResponse', index=16, number=4515,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCPerformManualOp', index=17, number=4516,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCPerformManualOpCompleted', index=18, number=4517,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCToGCReloadServerRegionSettings', index=19, number=4518,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8727,
  serialized_end=9382,
)
_sym_db.RegisterEnumDescriptor(_EGCBASEMSG)

EGCBaseMsg = enum_type_wrapper.EnumTypeWrapper(_EGCBASEMSG)
_EGCBASEPROTOOBJECTTYPES = _descriptor.EnumDescriptor(
  name='EGCBaseProtoObjectTypes',
  full_name='dota.EGCBaseProtoObjectTypes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProtoObjectPartyInvite', index=0, number=1001,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProtoObjectLobbyInvite', index=1, number=1002,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9384,
  serialized_end=9473,
)
_sym_db.RegisterEnumDescriptor(_EGCBASEPROTOOBJECTTYPES)

EGCBaseProtoObjectTypes = enum_type_wrapper.EnumTypeWrapper(_EGCBASEPROTOOBJECTTYPES)
_ECUSTOMGAMEINSTALLSTATUS = _descriptor.EnumDescriptor(
  name='ECustomGameInstallStatus',
  full_name='dota.ECustomGameInstallStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_Unknown', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_Ready', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_Busy', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedGeneric', index=3, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedInternalError', index=4, number=102,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_RequestedTimestampTooOld', index=5, number=103,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_RequestedTimestampTooNew', index=6, number=104,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_CRCMismatch', index=7, number=105,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedSteam', index=8, number=106,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedCanceled', index=9, number=107,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9476,
  serialized_end=9964,
)
_sym_db.RegisterEnumDescriptor(_ECUSTOMGAMEINSTALLSTATUS)

ECustomGameInstallStatus = enum_type_wrapper.EnumTypeWrapper(_ECUSTOMGAMEINSTALLSTATUS)
k_EMsgGCSystemMessage = 4001
k_EMsgGCReplicateConVars = 4002
k_EMsgGCConVarUpdated = 4003
k_EMsgGCInviteToParty = 4501
k_EMsgGCInvitationCreated = 4502
k_EMsgGCPartyInviteResponse = 4503
k_EMsgGCKickFromParty = 4504
k_EMsgGCLeaveParty = 4505
k_EMsgGCServerAvailable = 4506
k_EMsgGCClientConnectToServer = 4507
k_EMsgGCGameServerInfo = 4508
k_EMsgGCError = 4509
k_EMsgGCLANServerAvailable = 4511
k_EMsgGCInviteToLobby = 4512
k_EMsgGCLobbyInviteResponse = 4513
k_EMsgGCToClientPollFileRequest = 4514
k_EMsgGCToClientPollFileResponse = 4515
k_EMsgGCToGCPerformManualOp = 4516
k_EMsgGCToGCPerformManualOpCompleted = 4517
k_EMsgGCToGCReloadServerRegionSettings = 4518
k_EProtoObjectPartyInvite = 1001
k_EProtoObjectLobbyInvite = 1002
k_ECustomGameInstallStatus_Unknown = 0
k_ECustomGameInstallStatus_Ready = 1
k_ECustomGameInstallStatus_Busy = 2
k_ECustomGameInstallStatus_FailedGeneric = 101
k_ECustomGameInstallStatus_FailedInternalError = 102
k_ECustomGameInstallStatus_RequestedTimestampTooOld = 103
k_ECustomGameInstallStatus_RequestedTimestampTooNew = 104
k_ECustomGameInstallStatus_CRCMismatch = 105
k_ECustomGameInstallStatus_FailedSteam = 106
k_ECustomGameInstallStatus_FailedCanceled = 107


_CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS = _descriptor.EnumDescriptor(
  name='EExtractGems',
  full_name='dota.CMsgExtractGemsResponse.EExtractGems',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Succeeded', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_ToolIsInvalid', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_ItemIsInvalid', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_ToolCannotRemoveGem', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_FailedToRemoveGem', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6716,
  serialized_end=6929,
)
_sym_db.RegisterEnumDescriptor(_CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS)

_CMSGADDSOCKETRESPONSE_EADDSOCKET = _descriptor.EnumDescriptor(
  name='EAddSocket',
  full_name='dota.CMsgAddSocketResponse.EAddSocket',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Succeeded', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Failed_ToolIsInvalid', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Failed_ItemCannotBeSocketed', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Failed_FailedToAddSocket', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7164,
  serialized_end=7328,
)
_sym_db.RegisterEnumDescriptor(_CMSGADDSOCKETRESPONSE_EADDSOCKET)

_CMSGADDITEMTOSOCKETRESPONSE_EADDGEM = _descriptor.EnumDescriptor(
  name='EAddGem',
  full_name='dota.CMsgAddItemToSocketResponse.EAddGem',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Succeeded', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_GemIsInvalid', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_ItemIsInvalid', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_FailedToAddGem', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_InvalidGemTypeForSocket', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_InvalidGemTypeForHero', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_InvalidGemTypeForSlot', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_SocketContainsUnremovableGem', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7666,
  serialized_end=7985,
)
_sym_db.RegisterEnumDescriptor(_CMSGADDITEMTOSOCKETRESPONSE_EADDGEM)

_CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM = _descriptor.EnumDescriptor(
  name='EResetGem',
  full_name='dota.CMsgResetStrangeGemCountResponse.EResetGem',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Succeeded', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_FailedToResetGem', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_ItemIsInvalid', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_InvalidSocketId', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_SocketCannotBeReset', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8187,
  serialized_end=8383,
)
_sym_db.RegisterEnumDescriptor(_CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM)


_CGCSTOREPURCHASEINIT_LINEITEM = _descriptor.Descriptor(
  name='CGCStorePurchaseInit_LineItem',
  full_name='dota.CGCStorePurchaseInit_LineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_id', full_name='dota.CGCStorePurchaseInit_LineItem.item_def_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='dota.CGCStorePurchaseInit_LineItem.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost_in_local_currency', full_name='dota.CGCStorePurchaseInit_LineItem.cost_in_local_currency', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_type', full_name='dota.CGCStorePurchaseInit_LineItem.purchase_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_reference_id', full_name='dota.CGCStorePurchaseInit_LineItem.source_reference_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=207,
)


_CMSGGCSTOREPURCHASEINIT = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseInit',
  full_name='dota.CMsgGCStorePurchaseInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='dota.CMsgGCStorePurchaseInit.country', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='dota.CMsgGCStorePurchaseInit.language', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='dota.CMsgGCStorePurchaseInit.currency', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_items', full_name='dota.CMsgGCStorePurchaseInit.line_items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=345,
)


_CMSGGCSTOREPURCHASEINITRESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseInitResponse',
  full_name='dota.CMsgGCStorePurchaseInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCStorePurchaseInitResponse.result', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='dota.CMsgGCStorePurchaseInitResponse.txn_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=412,
)


_CMSGSYSTEMBROADCAST = _descriptor.Descriptor(
  name='CMsgSystemBroadcast',
  full_name='dota.CMsgSystemBroadcast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='dota.CMsgSystemBroadcast.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=452,
)


_CMSGCLIENTPINGDATA = _descriptor.Descriptor(
  name='CMsgClientPingData',
  full_name='dota.CMsgClientPingData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relay_codes', full_name='dota.CMsgClientPingData.relay_codes', index=0,
      number=4, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relay_pings', full_name='dota.CMsgClientPingData.relay_pings', index=1,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_codes', full_name='dota.CMsgClientPingData.region_codes', index=2,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_pings', full_name='dota.CMsgClientPingData.region_pings', index=3,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_ping_failed_bitmask', full_name='dota.CMsgClientPingData.region_ping_failed_bitmask', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=613,
)


_CMSGINVITETOPARTY = _descriptor.Descriptor(
  name='CMsgInviteToParty',
  full_name='dota.CMsgInviteToParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='dota.CMsgInviteToParty.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgInviteToParty.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='dota.CMsgInviteToParty.team_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='as_coach', full_name='dota.CMsgInviteToParty.as_coach', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='dota.CMsgInviteToParty.ping_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=757,
)


_CMSGINVITETOLOBBY = _descriptor.Descriptor(
  name='CMsgInviteToLobby',
  full_name='dota.CMsgInviteToLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='dota.CMsgInviteToLobby.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgInviteToLobby.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=820,
)


_CMSGINVITATIONCREATED = _descriptor.Descriptor(
  name='CMsgInvitationCreated',
  full_name='dota.CMsgInvitationCreated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dota.CMsgInvitationCreated.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='dota.CMsgInvitationCreated.steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_offline', full_name='dota.CMsgInvitationCreated.user_offline', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=903,
)


_CMSGPARTYINVITERESPONSE = _descriptor.Descriptor(
  name='CMsgPartyInviteResponse',
  full_name='dota.CMsgPartyInviteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='dota.CMsgPartyInviteResponse.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accept', full_name='dota.CMsgPartyInviteResponse.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgPartyInviteResponse.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='dota.CMsgPartyInviteResponse.ping_data', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=1034,
)


_CMSGLOBBYINVITERESPONSE = _descriptor.Descriptor(
  name='CMsgLobbyInviteResponse',
  full_name='dota.CMsgLobbyInviteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgLobbyInviteResponse.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accept', full_name='dota.CMsgLobbyInviteResponse.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgLobbyInviteResponse.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_game_crc', full_name='dota.CMsgLobbyInviteResponse.custom_game_crc', index=3,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_game_timestamp', full_name='dota.CMsgLobbyInviteResponse.custom_game_timestamp', index=4,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1176,
)


_CMSGKICKFROMPARTY = _descriptor.Descriptor(
  name='CMsgKickFromParty',
  full_name='dota.CMsgKickFromParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='dota.CMsgKickFromParty.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1178,
  serialized_end=1215,
)


_CMSGLEAVEPARTY = _descriptor.Descriptor(
  name='CMsgLeaveParty',
  full_name='dota.CMsgLeaveParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1233,
)


_CMSGCUSTOMGAMEINSTALLSTATUS = _descriptor.Descriptor(
  name='CMsgCustomGameInstallStatus',
  full_name='dota.CMsgCustomGameInstallStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='dota.CMsgCustomGameInstallStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='dota.CMsgCustomGameInstallStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latest_timestamp_from_steam', full_name='dota.CMsgCustomGameInstallStatus.latest_timestamp_from_steam', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1403,
)


_CMSGSERVERAVAILABLE = _descriptor.Descriptor(
  name='CMsgServerAvailable',
  full_name='dota.CMsgServerAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_install_status', full_name='dota.CMsgServerAvailable.custom_game_install_status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1497,
)


_CMSGLANSERVERAVAILABLE = _descriptor.Descriptor(
  name='CMsgLANServerAvailable',
  full_name='dota.CMsgLANServerAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='dota.CMsgLANServerAvailable.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1499,
  serialized_end=1541,
)


_CSOECONGAMEACCOUNTCLIENT = _descriptor.Descriptor(
  name='CSOEconGameAccountClient',
  full_name='dota.CSOEconGameAccountClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_backpack_slots', full_name='dota.CSOEconGameAccountClient.additional_backpack_slots', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trial_account', full_name='dota.CSOEconGameAccountClient.trial_account', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eligible_for_online_play', full_name='dota.CSOEconGameAccountClient.eligible_for_online_play', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='need_to_choose_most_helpful_friend', full_name='dota.CSOEconGameAccountClient.need_to_choose_most_helpful_friend', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_coaches_list', full_name='dota.CSOEconGameAccountClient.in_coaches_list', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_ban_expiration', full_name='dota.CSOEconGameAccountClient.trade_ban_expiration', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duel_ban_expiration', full_name='dota.CSOEconGameAccountClient.duel_ban_expiration', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='made_first_purchase', full_name='dota.CSOEconGameAccountClient.made_first_purchase', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=1842,
)


_CSOITEMCRITERIACONDITION = _descriptor.Descriptor(
  name='CSOItemCriteriaCondition',
  full_name='dota.CSOItemCriteriaCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='dota.CSOItemCriteriaCondition.op', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='dota.CSOItemCriteriaCondition.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required', full_name='dota.CSOItemCriteriaCondition.required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='dota.CSOItemCriteriaCondition.float_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='dota.CSOItemCriteriaCondition.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=1958,
)


_CSOITEMCRITERIA = _descriptor.Descriptor(
  name='CSOItemCriteria',
  full_name='dota.CSOItemCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_level', full_name='dota.CSOItemCriteria.item_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_quality', full_name='dota.CSOItemCriteria.item_quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_level_set', full_name='dota.CSOItemCriteria.item_level_set', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_quality_set', full_name='dota.CSOItemCriteria.item_quality_set', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_inventory', full_name='dota.CSOItemCriteria.initial_inventory', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_quantity', full_name='dota.CSOItemCriteria.initial_quantity', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_enabled_flag', full_name='dota.CSOItemCriteria.ignore_enabled_flag', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='dota.CSOItemCriteria.conditions', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recent_only', full_name='dota.CSOItemCriteria.recent_only', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1961,
  serialized_end=2225,
)


_CSOITEMRECIPE = _descriptor.Descriptor(
  name='CSOItemRecipe',
  full_name='dota.CSOItemRecipe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CSOItemRecipe.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CSOItemRecipe.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='n_a', full_name='dota.CSOItemRecipe.n_a', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desc_inputs', full_name='dota.CSOItemRecipe.desc_inputs', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desc_outputs', full_name='dota.CSOItemRecipe.desc_outputs', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='di_a', full_name='dota.CSOItemRecipe.di_a', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='di_b', full_name='dota.CSOItemRecipe.di_b', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='di_c', full_name='dota.CSOItemRecipe.di_c', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_a', full_name='dota.CSOItemRecipe.do_a', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_b', full_name='dota.CSOItemRecipe.do_b', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='do_c', full_name='dota.CSOItemRecipe.do_c', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requires_all_same_class', full_name='dota.CSOItemRecipe.requires_all_same_class', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requires_all_same_slot', full_name='dota.CSOItemRecipe.requires_all_same_slot', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='class_usage_for_output', full_name='dota.CSOItemRecipe.class_usage_for_output', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slot_usage_for_output', full_name='dota.CSOItemRecipe.slot_usage_for_output', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_for_output', full_name='dota.CSOItemRecipe.set_for_output', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_items_criteria', full_name='dota.CSOItemRecipe.input_items_criteria', index=16,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_items_criteria', full_name='dota.CSOItemRecipe.output_items_criteria', index=17,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='input_item_dupe_counts', full_name='dota.CSOItemRecipe.input_item_dupe_counts', index=18,
      number=22, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2228,
  serialized_end=2707,
)


_CMSGAPPLYSTRANGEPART = _descriptor.Descriptor(
  name='CMsgApplyStrangePart',
  full_name='dota.CMsgApplyStrangePart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strange_part_item_id', full_name='dota.CMsgApplyStrangePart.strange_part_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='dota.CMsgApplyStrangePart.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2709,
  serialized_end=2783,
)


_CMSGAPPLYPENNANTUPGRADE = _descriptor.Descriptor(
  name='CMsgApplyPennantUpgrade',
  full_name='dota.CMsgApplyPennantUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_item_id', full_name='dota.CMsgApplyPennantUpgrade.upgrade_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pennant_item_id', full_name='dota.CMsgApplyPennantUpgrade.pennant_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2785,
  serialized_end=2860,
)


_CMSGAPPLYEGGESSENCE = _descriptor.Descriptor(
  name='CMsgApplyEggEssence',
  full_name='dota.CMsgApplyEggEssence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='essence_item_id', full_name='dota.CMsgApplyEggEssence.essence_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egg_item_id', full_name='dota.CMsgApplyEggEssence.egg_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2862,
  serialized_end=2929,
)


_CSOECONITEMATTRIBUTE = _descriptor.Descriptor(
  name='CSOEconItemAttribute',
  full_name='dota.CSOEconItemAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CSOEconItemAttribute.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dota.CSOEconItemAttribute.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_bytes', full_name='dota.CSOEconItemAttribute.value_bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2931,
  serialized_end=3008,
)


_CSOECONITEMEQUIPPED = _descriptor.Descriptor(
  name='CSOEconItemEquipped',
  full_name='dota.CSOEconItemEquipped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_class', full_name='dota.CSOEconItemEquipped.new_class', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_slot', full_name='dota.CSOEconItemEquipped.new_slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3010,
  serialized_end=3068,
)


_CSOECONITEM = _descriptor.Descriptor(
  name='CSOEconItem',
  full_name='dota.CSOEconItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CSOEconItem.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSOEconItem.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='dota.CSOEconItem.inventory', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CSOEconItem.def_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='dota.CSOEconItem.quantity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='dota.CSOEconItem.level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CSOEconItem.quality', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='dota.CSOEconItem.flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='dota.CSOEconItem.origin', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='dota.CSOEconItem.attribute', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interior_item', full_name='dota.CSOEconItem.interior_item', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='dota.CSOEconItem.style', index=11,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_id', full_name='dota.CSOEconItem.original_id', index=12,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='equipped_state', full_name='dota.CSOEconItem.equipped_state', index=13,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3071,
  serialized_end=3432,
)


_CMSGSORTITEMS = _descriptor.Descriptor(
  name='CMsgSortItems',
  full_name='dota.CMsgSortItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sort_type', full_name='dota.CMsgSortItems.sort_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3434,
  serialized_end=3468,
)


_CSOECONCLAIMCODE = _descriptor.Descriptor(
  name='CSOEconClaimCode',
  full_name='dota.CSOEconClaimCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSOEconClaimCode.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='dota.CSOEconClaimCode.code_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_acquired', full_name='dota.CSOEconClaimCode.time_acquired', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dota.CSOEconClaimCode.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3470,
  serialized_end=3564,
)


_CMSGUPDATEITEMSCHEMA = _descriptor.Descriptor(
  name='CMsgUpdateItemSchema',
  full_name='dota.CMsgUpdateItemSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items_game', full_name='dota.CMsgUpdateItemSchema.items_game', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_schema_version', full_name='dota.CMsgUpdateItemSchema.item_schema_version', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items_game_url', full_name='dota.CMsgUpdateItemSchema.items_game_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3566,
  serialized_end=3661,
)


_CMSGGCERROR = _descriptor.Descriptor(
  name='CMsgGCError',
  full_name='dota.CMsgGCError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_text', full_name='dota.CMsgGCError.error_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3663,
  serialized_end=3696,
)


_CMSGREQUESTINVENTORYREFRESH = _descriptor.Descriptor(
  name='CMsgRequestInventoryRefresh',
  full_name='dota.CMsgRequestInventoryRefresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3698,
  serialized_end=3727,
)


_CMSGCONVARVALUE = _descriptor.Descriptor(
  name='CMsgConVarValue',
  full_name='dota.CMsgConVarValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dota.CMsgConVarValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dota.CMsgConVarValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3729,
  serialized_end=3775,
)


_CMSGREPLICATECONVARS = _descriptor.Descriptor(
  name='CMsgReplicateConVars',
  full_name='dota.CMsgReplicateConVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='convars', full_name='dota.CMsgReplicateConVars.convars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3777,
  serialized_end=3839,
)


_CMSGITEMACKNOWLEDGED = _descriptor.Descriptor(
  name='CMsgItemAcknowledged',
  full_name='dota.CMsgItemAcknowledged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgItemAcknowledged.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='dota.CMsgItemAcknowledged.inventory', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CMsgItemAcknowledged.def_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality', full_name='dota.CMsgItemAcknowledged.quality', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rarity', full_name='dota.CMsgItemAcknowledged.rarity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='dota.CMsgItemAcknowledged.origin', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3842,
  serialized_end=3971,
)


_CMSGSETITEMPOSITIONS_ITEMPOSITION = _descriptor.Descriptor(
  name='ItemPosition',
  full_name='dota.CMsgSetItemPositions.ItemPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgSetItemPositions.ItemPosition.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='dota.CMsgSetItemPositions.ItemPosition.position', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4063,
  serialized_end=4112,
)

_CMSGSETITEMPOSITIONS = _descriptor.Descriptor(
  name='CMsgSetItemPositions',
  full_name='dota.CMsgSetItemPositions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_positions', full_name='dota.CMsgSetItemPositions.item_positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSETITEMPOSITIONS_ITEMPOSITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3974,
  serialized_end=4112,
)


_CMSGGCNAMEITEMNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCNameItemNotification',
  full_name='dota.CMsgGCNameItemNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_steamid', full_name='dota.CMsgGCNameItemNotification.player_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='dota.CMsgGCNameItemNotification.item_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_name_custom', full_name='dota.CMsgGCNameItemNotification.item_name_custom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4114,
  serialized_end=4216,
)


_CMSGGCCLIENTDISPLAYNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCClientDisplayNotification',
  full_name='dota.CMsgGCClientDisplayNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_title_localization_key', full_name='dota.CMsgGCClientDisplayNotification.notification_title_localization_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notification_body_localization_key', full_name='dota.CMsgGCClientDisplayNotification.notification_body_localization_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_substring_keys', full_name='dota.CMsgGCClientDisplayNotification.body_substring_keys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body_substring_values', full_name='dota.CMsgGCClientDisplayNotification.body_substring_values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4219,
  serialized_end=4401,
)


_CMSGGCSHOWITEMSPICKEDUP = _descriptor.Descriptor(
  name='CMsgGCShowItemsPickedUp',
  full_name='dota.CMsgGCShowItemsPickedUp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_steamid', full_name='dota.CMsgGCShowItemsPickedUp.player_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4403,
  serialized_end=4452,
)


_CMSGGCINCREMENTKILLCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCIncrementKillCountResponse',
  full_name='dota.CMsgGCIncrementKillCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='killer_account_id', full_name='dota.CMsgGCIncrementKillCountResponse.killer_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_kills', full_name='dota.CMsgGCIncrementKillCountResponse.num_kills', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='dota.CMsgGCIncrementKillCountResponse.item_def', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level_type', full_name='dota.CMsgGCIncrementKillCountResponse.level_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4454,
  serialized_end=4578,
)


_CSOECONITEMDROPRATEBONUS = _descriptor.Descriptor(
  name='CSOEconItemDropRateBonus',
  full_name='dota.CSOEconItemDropRateBonus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSOEconItemDropRateBonus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration_date', full_name='dota.CSOEconItemDropRateBonus.expiration_date', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonus', full_name='dota.CSOEconItemDropRateBonus.bonus', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bonus_count', full_name='dota.CSOEconItemDropRateBonus.bonus_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CSOEconItemDropRateBonus.item_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CSOEconItemDropRateBonus.def_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seconds_left', full_name='dota.CSOEconItemDropRateBonus.seconds_left', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='booster_type', full_name='dota.CSOEconItemDropRateBonus.booster_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4581,
  serialized_end=4786,
)


_CSOECONITEMLEAGUEVIEWPASS = _descriptor.Descriptor(
  name='CSOEconItemLeagueViewPass',
  full_name='dota.CSOEconItemLeagueViewPass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSOEconItemLeagueViewPass.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CSOEconItemLeagueViewPass.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\200\227\"\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='itemindex', full_name='dota.CSOEconItemLeagueViewPass.itemindex', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grant_reason', full_name='dota.CSOEconItemLeagueViewPass.grant_reason', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4788,
  serialized_end=4907,
)


_CSOECONITEMEVENTTICKET = _descriptor.Descriptor(
  name='CSOEconItemEventTicket',
  full_name='dota.CSOEconItemEventTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSOEconItemEventTicket.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='dota.CSOEconItemEventTicket.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CSOEconItemEventTicket.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4909,
  serialized_end=4988,
)


_CSOECONITEMTOURNAMENTPASSPORT = _descriptor.Descriptor(
  name='CSOEconItemTournamentPassport',
  full_name='dota.CSOEconItemTournamentPassport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CSOEconItemTournamentPassport.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='dota.CSOEconItemTournamentPassport.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CSOEconItemTournamentPassport.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_purchaser_id', full_name='dota.CSOEconItemTournamentPassport.original_purchaser_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='passports_bought', full_name='dota.CSOEconItemTournamentPassport.passports_bought', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CSOEconItemTournamentPassport.version', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='dota.CSOEconItemTournamentPassport.def_index', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward_flags', full_name='dota.CSOEconItemTournamentPassport.reward_flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4991,
  serialized_end=5193,
)


_CMSGGCSTOREPURCHASECANCEL = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseCancel',
  full_name='dota.CMsgGCStorePurchaseCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='dota.CMsgGCStorePurchaseCancel.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5195,
  serialized_end=5238,
)


_CMSGGCSTOREPURCHASECANCELRESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseCancelResponse',
  full_name='dota.CMsgGCStorePurchaseCancelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCStorePurchaseCancelResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5240,
  serialized_end=5291,
)


_CMSGGCSTOREPURCHASEFINALIZE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseFinalize',
  full_name='dota.CMsgGCStorePurchaseFinalize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='dota.CMsgGCStorePurchaseFinalize.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5293,
  serialized_end=5338,
)


_CMSGGCSTOREPURCHASEFINALIZERESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseFinalizeResponse',
  full_name='dota.CMsgGCStorePurchaseFinalizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='dota.CMsgGCStorePurchaseFinalizeResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='dota.CMsgGCStorePurchaseFinalizeResponse.item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5340,
  serialized_end=5411,
)


_CMSGGCTOGCBANNEDWORDLISTUPDATED = _descriptor.Descriptor(
  name='CMsgGCToGCBannedWordListUpdated',
  full_name='dota.CMsgGCToGCBannedWordListUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dota.CMsgGCToGCBannedWordListUpdated.group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5413,
  serialized_end=5464,
)


_CMSGGCTOGCDIRTYSDOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCDirtySDOCache',
  full_name='dota.CMsgGCToGCDirtySDOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdo_type', full_name='dota.CMsgGCToGCDirtySDOCache.sdo_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_uint64', full_name='dota.CMsgGCToGCDirtySDOCache.key_uint64', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5466,
  serialized_end=5529,
)


_CMSGGCTOGCDIRTYMULTIPLESDOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCDirtyMultipleSDOCache',
  full_name='dota.CMsgGCToGCDirtyMultipleSDOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdo_type', full_name='dota.CMsgGCToGCDirtyMultipleSDOCache.sdo_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_uint64', full_name='dota.CMsgGCToGCDirtyMultipleSDOCache.key_uint64', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5531,
  serialized_end=5602,
)


_CMSGGCTOGCAPPLYLOCALIZATIONDIFF = _descriptor.Descriptor(
  name='CMsgGCToGCApplyLocalizationDiff',
  full_name='dota.CMsgGCToGCApplyLocalizationDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='dota.CMsgGCToGCApplyLocalizationDiff.language', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packed_diff', full_name='dota.CMsgGCToGCApplyLocalizationDiff.packed_diff', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5604,
  serialized_end=5676,
)


_CMSGGCTOGCAPPLYLOCALIZATIONDIFFRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCApplyLocalizationDiffResponse',
  full_name='dota.CMsgGCToGCApplyLocalizationDiffResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCToGCApplyLocalizationDiffResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5678,
  serialized_end=5736,
)


_CMSGGCCOLLECTITEM = _descriptor.Descriptor(
  name='CMsgGCCollectItem',
  full_name='dota.CMsgGCCollectItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_item_id', full_name='dota.CMsgGCCollectItem.collection_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_item_id', full_name='dota.CMsgGCCollectItem.subject_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5738,
  serialized_end=5810,
)


_CMSGSDONOMEMCACHED = _descriptor.Descriptor(
  name='CMsgSDONoMemcached',
  full_name='dota.CMsgSDONoMemcached',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5812,
  serialized_end=5832,
)


_CMSGGCTOGCUPDATESQLKEYVALUE = _descriptor.Descriptor(
  name='CMsgGCToGCUpdateSQLKeyValue',
  full_name='dota.CMsgGCToGCUpdateSQLKeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_name', full_name='dota.CMsgGCToGCUpdateSQLKeyValue.key_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5834,
  serialized_end=5881,
)


_CMSGGCSERVERVERSIONUPDATED = _descriptor.Descriptor(
  name='CMsgGCServerVersionUpdated',
  full_name='dota.CMsgGCServerVersionUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_version', full_name='dota.CMsgGCServerVersionUpdated.server_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5883,
  serialized_end=5935,
)


_CMSGGCCLIENTVERSIONUPDATED = _descriptor.Descriptor(
  name='CMsgGCClientVersionUpdated',
  full_name='dota.CMsgGCClientVersionUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgGCClientVersionUpdated.client_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5937,
  serialized_end=5989,
)


_CMSGGCTOGCWEBAPIACCOUNTCHANGED = _descriptor.Descriptor(
  name='CMsgGCToGCWebAPIAccountChanged',
  full_name='dota.CMsgGCToGCWebAPIAccountChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5991,
  serialized_end=6023,
)


_CMSGRECIPECOMPONENT = _descriptor.Descriptor(
  name='CMsgRecipeComponent',
  full_name='dota.CMsgRecipeComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject_item_id', full_name='dota.CMsgRecipeComponent.subject_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='dota.CMsgRecipeComponent.attribute_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6025,
  serialized_end=6096,
)


_CMSGFULFILLDYNAMICRECIPECOMPONENT = _descriptor.Descriptor(
  name='CMsgFulfillDynamicRecipeComponent',
  full_name='dota.CMsgFulfillDynamicRecipeComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='dota.CMsgFulfillDynamicRecipeComponent.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consumption_components', full_name='dota.CMsgFulfillDynamicRecipeComponent.consumption_components', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6098,
  serialized_end=6214,
)


_CMSGGCCLIENTMARKETDATAREQUEST = _descriptor.Descriptor(
  name='CMsgGCClientMarketDataRequest',
  full_name='dota.CMsgGCClientMarketDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_currency', full_name='dota.CMsgGCClientMarketDataRequest.user_currency', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6216,
  serialized_end=6270,
)


_CMSGGCCLIENTMARKETDATAENTRY = _descriptor.Descriptor(
  name='CMsgGCClientMarketDataEntry',
  full_name='dota.CMsgGCClientMarketDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='dota.CMsgGCClientMarketDataEntry.item_def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_quality', full_name='dota.CMsgGCClientMarketDataEntry.item_quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_sell_listings', full_name='dota.CMsgGCClientMarketDataEntry.item_sell_listings', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_in_local_currency', full_name='dota.CMsgGCClientMarketDataEntry.price_in_local_currency', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6273,
  serialized_end=6409,
)


_CMSGGCCLIENTMARKETDATA = _descriptor.Descriptor(
  name='CMsgGCClientMarketData',
  full_name='dota.CMsgGCClientMarketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='dota.CMsgGCClientMarketData.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6411,
  serialized_end=6487,
)


_CMSGEXTRACTGEMS = _descriptor.Descriptor(
  name='CMsgExtractGems',
  full_name='dota.CMsgExtractGems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='dota.CMsgExtractGems.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='dota.CMsgExtractGems.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_socket_id', full_name='dota.CMsgExtractGems.item_socket_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=65535,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6489,
  serialized_end=6581,
)


_CMSGEXTRACTGEMSRESPONSE = _descriptor.Descriptor(
  name='CMsgExtractGemsResponse',
  full_name='dota.CMsgExtractGemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgExtractGemsResponse.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgExtractGemsResponse.response', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6584,
  serialized_end=6929,
)


_CMSGADDSOCKET = _descriptor.Descriptor(
  name='CMsgAddSocket',
  full_name='dota.CMsgAddSocket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='dota.CMsgAddSocket.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='dota.CMsgAddSocket.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unusual', full_name='dota.CMsgAddSocket.unusual', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6931,
  serialized_end=7007,
)


_CMSGADDSOCKETRESPONSE = _descriptor.Descriptor(
  name='CMsgAddSocketResponse',
  full_name='dota.CMsgAddSocketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='dota.CMsgAddSocketResponse.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_socket_index', full_name='dota.CMsgAddSocketResponse.updated_socket_index', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgAddSocketResponse.response', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGADDSOCKETRESPONSE_EADDSOCKET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7010,
  serialized_end=7328,
)


_CMSGADDITEMTOSOCKETDATA = _descriptor.Descriptor(
  name='CMsgAddItemToSocketData',
  full_name='dota.CMsgAddItemToSocketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gem_item_id', full_name='dota.CMsgAddItemToSocketData.gem_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='socket_index', full_name='dota.CMsgAddItemToSocketData.socket_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7330,
  serialized_end=7398,
)


_CMSGADDITEMTOSOCKET = _descriptor.Descriptor(
  name='CMsgAddItemToSocket',
  full_name='dota.CMsgAddItemToSocket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='dota.CMsgAddItemToSocket.item_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gems_to_socket', full_name='dota.CMsgAddItemToSocket.gems_to_socket', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7400,
  serialized_end=7498,
)


_CMSGADDITEMTOSOCKETRESPONSE = _descriptor.Descriptor(
  name='CMsgAddItemToSocketResponse',
  full_name='dota.CMsgAddItemToSocketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='dota.CMsgAddItemToSocketResponse.item_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_socket_index', full_name='dota.CMsgAddItemToSocketResponse.updated_socket_index', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgAddItemToSocketResponse.response', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGADDITEMTOSOCKETRESPONSE_EADDGEM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7501,
  serialized_end=7985,
)


_CMSGRESETSTRANGEGEMCOUNT = _descriptor.Descriptor(
  name='CMsgResetStrangeGemCount',
  full_name='dota.CMsgResetStrangeGemCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='dota.CMsgResetStrangeGemCount.item_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='socket_index', full_name='dota.CMsgResetStrangeGemCount.socket_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7987,
  serialized_end=8057,
)


_CMSGRESETSTRANGEGEMCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgResetStrangeGemCountResponse',
  full_name='dota.CMsgResetStrangeGemCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='dota.CMsgResetStrangeGemCountResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8060,
  serialized_end=8383,
)


_CMSGGCTOCLIENTPOLLFILEREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientPollFileRequest',
  full_name='dota.CMsgGCToClientPollFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='dota.CMsgGCToClientPollFileRequest.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='dota.CMsgGCToClientPollFileRequest.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poll_id', full_name='dota.CMsgGCToClientPollFileRequest.poll_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8385,
  serialized_end=8476,
)


_CMSGGCTOCLIENTPOLLFILERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientPollFileResponse',
  full_name='dota.CMsgGCToClientPollFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poll_id', full_name='dota.CMsgGCToClientPollFileResponse.poll_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='dota.CMsgGCToClientPollFileResponse.file_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8478,
  serialized_end=8546,
)


_CMSGGCTOGCPERFORMMANUALOP = _descriptor.Descriptor(
  name='CMsgGCToGCPerformManualOp',
  full_name='dota.CMsgGCToGCPerformManualOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op_id', full_name='dota.CMsgGCToGCPerformManualOp.op_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_code', full_name='dota.CMsgGCToGCPerformManualOp.group_code', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8548,
  serialized_end=8610,
)


_CMSGGCTOGCPERFORMMANUALOPCOMPLETED = _descriptor.Descriptor(
  name='CMsgGCToGCPerformManualOpCompleted',
  full_name='dota.CMsgGCToGCPerformManualOpCompleted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCToGCPerformManualOpCompleted.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_gc', full_name='dota.CMsgGCToGCPerformManualOpCompleted.source_gc', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8612,
  serialized_end=8684,
)


_CMSGGCTOGCRELOADSERVERREGIONSETTINGS = _descriptor.Descriptor(
  name='CMsgGCToGCReloadServerRegionSettings',
  full_name='dota.CMsgGCToGCReloadServerRegionSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8686,
  serialized_end=8724,
)

_CMSGGCSTOREPURCHASEINIT.fields_by_name['line_items'].message_type = _CGCSTOREPURCHASEINIT_LINEITEM
_CMSGINVITETOPARTY.fields_by_name['ping_data'].message_type = _CMSGCLIENTPINGDATA
_CMSGPARTYINVITERESPONSE.fields_by_name['ping_data'].message_type = _CMSGCLIENTPINGDATA
_CMSGCUSTOMGAMEINSTALLSTATUS.fields_by_name['status'].enum_type = _ECUSTOMGAMEINSTALLSTATUS
_CMSGSERVERAVAILABLE.fields_by_name['custom_game_install_status'].message_type = _CMSGCUSTOMGAMEINSTALLSTATUS
_CSOITEMCRITERIA.fields_by_name['conditions'].message_type = _CSOITEMCRITERIACONDITION
_CSOITEMRECIPE.fields_by_name['input_items_criteria'].message_type = _CSOITEMCRITERIA
_CSOITEMRECIPE.fields_by_name['output_items_criteria'].message_type = _CSOITEMCRITERIA
_CSOECONITEM.fields_by_name['attribute'].message_type = _CSOECONITEMATTRIBUTE
_CSOECONITEM.fields_by_name['interior_item'].message_type = _CSOECONITEM
_CSOECONITEM.fields_by_name['equipped_state'].message_type = _CSOECONITEMEQUIPPED
_CMSGREPLICATECONVARS.fields_by_name['convars'].message_type = _CMSGCONVARVALUE
_CMSGSETITEMPOSITIONS_ITEMPOSITION.containing_type = _CMSGSETITEMPOSITIONS
_CMSGSETITEMPOSITIONS.fields_by_name['item_positions'].message_type = _CMSGSETITEMPOSITIONS_ITEMPOSITION
_CMSGFULFILLDYNAMICRECIPECOMPONENT.fields_by_name['consumption_components'].message_type = _CMSGRECIPECOMPONENT
_CMSGGCCLIENTMARKETDATA.fields_by_name['entries'].message_type = _CMSGGCCLIENTMARKETDATAENTRY
_CMSGEXTRACTGEMSRESPONSE.fields_by_name['response'].enum_type = _CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS
_CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS.containing_type = _CMSGEXTRACTGEMSRESPONSE
_CMSGADDSOCKETRESPONSE.fields_by_name['response'].enum_type = _CMSGADDSOCKETRESPONSE_EADDSOCKET
_CMSGADDSOCKETRESPONSE_EADDSOCKET.containing_type = _CMSGADDSOCKETRESPONSE
_CMSGADDITEMTOSOCKET.fields_by_name['gems_to_socket'].message_type = _CMSGADDITEMTOSOCKETDATA
_CMSGADDITEMTOSOCKETRESPONSE.fields_by_name['response'].enum_type = _CMSGADDITEMTOSOCKETRESPONSE_EADDGEM
_CMSGADDITEMTOSOCKETRESPONSE_EADDGEM.containing_type = _CMSGADDITEMTOSOCKETRESPONSE
_CMSGRESETSTRANGEGEMCOUNTRESPONSE.fields_by_name['response'].enum_type = _CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM
_CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM.containing_type = _CMSGRESETSTRANGEGEMCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CGCStorePurchaseInit_LineItem'] = _CGCSTOREPURCHASEINIT_LINEITEM
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseInit'] = _CMSGGCSTOREPURCHASEINIT
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseInitResponse'] = _CMSGGCSTOREPURCHASEINITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgSystemBroadcast'] = _CMSGSYSTEMBROADCAST
DESCRIPTOR.message_types_by_name['CMsgClientPingData'] = _CMSGCLIENTPINGDATA
DESCRIPTOR.message_types_by_name['CMsgInviteToParty'] = _CMSGINVITETOPARTY
DESCRIPTOR.message_types_by_name['CMsgInviteToLobby'] = _CMSGINVITETOLOBBY
DESCRIPTOR.message_types_by_name['CMsgInvitationCreated'] = _CMSGINVITATIONCREATED
DESCRIPTOR.message_types_by_name['CMsgPartyInviteResponse'] = _CMSGPARTYINVITERESPONSE
DESCRIPTOR.message_types_by_name['CMsgLobbyInviteResponse'] = _CMSGLOBBYINVITERESPONSE
DESCRIPTOR.message_types_by_name['CMsgKickFromParty'] = _CMSGKICKFROMPARTY
DESCRIPTOR.message_types_by_name['CMsgLeaveParty'] = _CMSGLEAVEPARTY
DESCRIPTOR.message_types_by_name['CMsgCustomGameInstallStatus'] = _CMSGCUSTOMGAMEINSTALLSTATUS
DESCRIPTOR.message_types_by_name['CMsgServerAvailable'] = _CMSGSERVERAVAILABLE
DESCRIPTOR.message_types_by_name['CMsgLANServerAvailable'] = _CMSGLANSERVERAVAILABLE
DESCRIPTOR.message_types_by_name['CSOEconGameAccountClient'] = _CSOECONGAMEACCOUNTCLIENT
DESCRIPTOR.message_types_by_name['CSOItemCriteriaCondition'] = _CSOITEMCRITERIACONDITION
DESCRIPTOR.message_types_by_name['CSOItemCriteria'] = _CSOITEMCRITERIA
DESCRIPTOR.message_types_by_name['CSOItemRecipe'] = _CSOITEMRECIPE
DESCRIPTOR.message_types_by_name['CMsgApplyStrangePart'] = _CMSGAPPLYSTRANGEPART
DESCRIPTOR.message_types_by_name['CMsgApplyPennantUpgrade'] = _CMSGAPPLYPENNANTUPGRADE
DESCRIPTOR.message_types_by_name['CMsgApplyEggEssence'] = _CMSGAPPLYEGGESSENCE
DESCRIPTOR.message_types_by_name['CSOEconItemAttribute'] = _CSOECONITEMATTRIBUTE
DESCRIPTOR.message_types_by_name['CSOEconItemEquipped'] = _CSOECONITEMEQUIPPED
DESCRIPTOR.message_types_by_name['CSOEconItem'] = _CSOECONITEM
DESCRIPTOR.message_types_by_name['CMsgSortItems'] = _CMSGSORTITEMS
DESCRIPTOR.message_types_by_name['CSOEconClaimCode'] = _CSOECONCLAIMCODE
DESCRIPTOR.message_types_by_name['CMsgUpdateItemSchema'] = _CMSGUPDATEITEMSCHEMA
DESCRIPTOR.message_types_by_name['CMsgGCError'] = _CMSGGCERROR
DESCRIPTOR.message_types_by_name['CMsgRequestInventoryRefresh'] = _CMSGREQUESTINVENTORYREFRESH
DESCRIPTOR.message_types_by_name['CMsgConVarValue'] = _CMSGCONVARVALUE
DESCRIPTOR.message_types_by_name['CMsgReplicateConVars'] = _CMSGREPLICATECONVARS
DESCRIPTOR.message_types_by_name['CMsgItemAcknowledged'] = _CMSGITEMACKNOWLEDGED
DESCRIPTOR.message_types_by_name['CMsgSetItemPositions'] = _CMSGSETITEMPOSITIONS
DESCRIPTOR.message_types_by_name['CMsgGCNameItemNotification'] = _CMSGGCNAMEITEMNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCClientDisplayNotification'] = _CMSGGCCLIENTDISPLAYNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCShowItemsPickedUp'] = _CMSGGCSHOWITEMSPICKEDUP
DESCRIPTOR.message_types_by_name['CMsgGCIncrementKillCountResponse'] = _CMSGGCINCREMENTKILLCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CSOEconItemDropRateBonus'] = _CSOECONITEMDROPRATEBONUS
DESCRIPTOR.message_types_by_name['CSOEconItemLeagueViewPass'] = _CSOECONITEMLEAGUEVIEWPASS
DESCRIPTOR.message_types_by_name['CSOEconItemEventTicket'] = _CSOECONITEMEVENTTICKET
DESCRIPTOR.message_types_by_name['CSOEconItemTournamentPassport'] = _CSOECONITEMTOURNAMENTPASSPORT
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseCancel'] = _CMSGGCSTOREPURCHASECANCEL
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseCancelResponse'] = _CMSGGCSTOREPURCHASECANCELRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseFinalize'] = _CMSGGCSTOREPURCHASEFINALIZE
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseFinalizeResponse'] = _CMSGGCSTOREPURCHASEFINALIZERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCBannedWordListUpdated'] = _CMSGGCTOGCBANNEDWORDLISTUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCToGCDirtySDOCache'] = _CMSGGCTOGCDIRTYSDOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCDirtyMultipleSDOCache'] = _CMSGGCTOGCDIRTYMULTIPLESDOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCApplyLocalizationDiff'] = _CMSGGCTOGCAPPLYLOCALIZATIONDIFF
DESCRIPTOR.message_types_by_name['CMsgGCToGCApplyLocalizationDiffResponse'] = _CMSGGCTOGCAPPLYLOCALIZATIONDIFFRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCCollectItem'] = _CMSGGCCOLLECTITEM
DESCRIPTOR.message_types_by_name['CMsgSDONoMemcached'] = _CMSGSDONOMEMCACHED
DESCRIPTOR.message_types_by_name['CMsgGCToGCUpdateSQLKeyValue'] = _CMSGGCTOGCUPDATESQLKEYVALUE
DESCRIPTOR.message_types_by_name['CMsgGCServerVersionUpdated'] = _CMSGGCSERVERVERSIONUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCClientVersionUpdated'] = _CMSGGCCLIENTVERSIONUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCToGCWebAPIAccountChanged'] = _CMSGGCTOGCWEBAPIACCOUNTCHANGED
DESCRIPTOR.message_types_by_name['CMsgRecipeComponent'] = _CMSGRECIPECOMPONENT
DESCRIPTOR.message_types_by_name['CMsgFulfillDynamicRecipeComponent'] = _CMSGFULFILLDYNAMICRECIPECOMPONENT
DESCRIPTOR.message_types_by_name['CMsgGCClientMarketDataRequest'] = _CMSGGCCLIENTMARKETDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCClientMarketDataEntry'] = _CMSGGCCLIENTMARKETDATAENTRY
DESCRIPTOR.message_types_by_name['CMsgGCClientMarketData'] = _CMSGGCCLIENTMARKETDATA
DESCRIPTOR.message_types_by_name['CMsgExtractGems'] = _CMSGEXTRACTGEMS
DESCRIPTOR.message_types_by_name['CMsgExtractGemsResponse'] = _CMSGEXTRACTGEMSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgAddSocket'] = _CMSGADDSOCKET
DESCRIPTOR.message_types_by_name['CMsgAddSocketResponse'] = _CMSGADDSOCKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgAddItemToSocketData'] = _CMSGADDITEMTOSOCKETDATA
DESCRIPTOR.message_types_by_name['CMsgAddItemToSocket'] = _CMSGADDITEMTOSOCKET
DESCRIPTOR.message_types_by_name['CMsgAddItemToSocketResponse'] = _CMSGADDITEMTOSOCKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgResetStrangeGemCount'] = _CMSGRESETSTRANGEGEMCOUNT
DESCRIPTOR.message_types_by_name['CMsgResetStrangeGemCountResponse'] = _CMSGRESETSTRANGEGEMCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToClientPollFileRequest'] = _CMSGGCTOCLIENTPOLLFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientPollFileResponse'] = _CMSGGCTOCLIENTPOLLFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCPerformManualOp'] = _CMSGGCTOGCPERFORMMANUALOP
DESCRIPTOR.message_types_by_name['CMsgGCToGCPerformManualOpCompleted'] = _CMSGGCTOGCPERFORMMANUALOPCOMPLETED
DESCRIPTOR.message_types_by_name['CMsgGCToGCReloadServerRegionSettings'] = _CMSGGCTOGCRELOADSERVERREGIONSETTINGS
DESCRIPTOR.enum_types_by_name['EGCBaseMsg'] = _EGCBASEMSG
DESCRIPTOR.enum_types_by_name['EGCBaseProtoObjectTypes'] = _EGCBASEPROTOOBJECTTYPES
DESCRIPTOR.enum_types_by_name['ECustomGameInstallStatus'] = _ECUSTOMGAMEINSTALLSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CGCStorePurchaseInit_LineItem = _reflection.GeneratedProtocolMessageType('CGCStorePurchaseInit_LineItem', (_message.Message,), dict(
  DESCRIPTOR = _CGCSTOREPURCHASEINIT_LINEITEM,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCStorePurchaseInit_LineItem)
  ))
_sym_db.RegisterMessage(CGCStorePurchaseInit_LineItem)

CMsgGCStorePurchaseInit = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseInit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEINIT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCStorePurchaseInit)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseInit)

CMsgGCStorePurchaseInitResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseInitResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEINITRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCStorePurchaseInitResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseInitResponse)

CMsgSystemBroadcast = _reflection.GeneratedProtocolMessageType('CMsgSystemBroadcast', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSYSTEMBROADCAST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSystemBroadcast)
  ))
_sym_db.RegisterMessage(CMsgSystemBroadcast)

CMsgClientPingData = _reflection.GeneratedProtocolMessageType('CMsgClientPingData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTPINGDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientPingData)
  ))
_sym_db.RegisterMessage(CMsgClientPingData)

CMsgInviteToParty = _reflection.GeneratedProtocolMessageType('CMsgInviteToParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITETOPARTY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgInviteToParty)
  ))
_sym_db.RegisterMessage(CMsgInviteToParty)

CMsgInviteToLobby = _reflection.GeneratedProtocolMessageType('CMsgInviteToLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITETOLOBBY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgInviteToLobby)
  ))
_sym_db.RegisterMessage(CMsgInviteToLobby)

CMsgInvitationCreated = _reflection.GeneratedProtocolMessageType('CMsgInvitationCreated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITATIONCREATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgInvitationCreated)
  ))
_sym_db.RegisterMessage(CMsgInvitationCreated)

CMsgPartyInviteResponse = _reflection.GeneratedProtocolMessageType('CMsgPartyInviteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPARTYINVITERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgPartyInviteResponse)
  ))
_sym_db.RegisterMessage(CMsgPartyInviteResponse)

CMsgLobbyInviteResponse = _reflection.GeneratedProtocolMessageType('CMsgLobbyInviteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLOBBYINVITERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgLobbyInviteResponse)
  ))
_sym_db.RegisterMessage(CMsgLobbyInviteResponse)

CMsgKickFromParty = _reflection.GeneratedProtocolMessageType('CMsgKickFromParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGKICKFROMPARTY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgKickFromParty)
  ))
_sym_db.RegisterMessage(CMsgKickFromParty)

CMsgLeaveParty = _reflection.GeneratedProtocolMessageType('CMsgLeaveParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAVEPARTY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgLeaveParty)
  ))
_sym_db.RegisterMessage(CMsgLeaveParty)

CMsgCustomGameInstallStatus = _reflection.GeneratedProtocolMessageType('CMsgCustomGameInstallStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCUSTOMGAMEINSTALLSTATUS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgCustomGameInstallStatus)
  ))
_sym_db.RegisterMessage(CMsgCustomGameInstallStatus)

CMsgServerAvailable = _reflection.GeneratedProtocolMessageType('CMsgServerAvailable', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERAVAILABLE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgServerAvailable)
  ))
_sym_db.RegisterMessage(CMsgServerAvailable)

CMsgLANServerAvailable = _reflection.GeneratedProtocolMessageType('CMsgLANServerAvailable', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLANSERVERAVAILABLE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgLANServerAvailable)
  ))
_sym_db.RegisterMessage(CMsgLANServerAvailable)

CSOEconGameAccountClient = _reflection.GeneratedProtocolMessageType('CSOEconGameAccountClient', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONGAMEACCOUNTCLIENT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconGameAccountClient)
  ))
_sym_db.RegisterMessage(CSOEconGameAccountClient)

CSOItemCriteriaCondition = _reflection.GeneratedProtocolMessageType('CSOItemCriteriaCondition', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMCRITERIACONDITION,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOItemCriteriaCondition)
  ))
_sym_db.RegisterMessage(CSOItemCriteriaCondition)

CSOItemCriteria = _reflection.GeneratedProtocolMessageType('CSOItemCriteria', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMCRITERIA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOItemCriteria)
  ))
_sym_db.RegisterMessage(CSOItemCriteria)

CSOItemRecipe = _reflection.GeneratedProtocolMessageType('CSOItemRecipe', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMRECIPE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOItemRecipe)
  ))
_sym_db.RegisterMessage(CSOItemRecipe)

CMsgApplyStrangePart = _reflection.GeneratedProtocolMessageType('CMsgApplyStrangePart', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYSTRANGEPART,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgApplyStrangePart)
  ))
_sym_db.RegisterMessage(CMsgApplyStrangePart)

CMsgApplyPennantUpgrade = _reflection.GeneratedProtocolMessageType('CMsgApplyPennantUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYPENNANTUPGRADE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgApplyPennantUpgrade)
  ))
_sym_db.RegisterMessage(CMsgApplyPennantUpgrade)

CMsgApplyEggEssence = _reflection.GeneratedProtocolMessageType('CMsgApplyEggEssence', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYEGGESSENCE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgApplyEggEssence)
  ))
_sym_db.RegisterMessage(CMsgApplyEggEssence)

CSOEconItemAttribute = _reflection.GeneratedProtocolMessageType('CSOEconItemAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMATTRIBUTE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItemAttribute)
  ))
_sym_db.RegisterMessage(CSOEconItemAttribute)

CSOEconItemEquipped = _reflection.GeneratedProtocolMessageType('CSOEconItemEquipped', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMEQUIPPED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItemEquipped)
  ))
_sym_db.RegisterMessage(CSOEconItemEquipped)

CSOEconItem = _reflection.GeneratedProtocolMessageType('CSOEconItem', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEM,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItem)
  ))
_sym_db.RegisterMessage(CSOEconItem)

CMsgSortItems = _reflection.GeneratedProtocolMessageType('CMsgSortItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSORTITEMS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSortItems)
  ))
_sym_db.RegisterMessage(CMsgSortItems)

CSOEconClaimCode = _reflection.GeneratedProtocolMessageType('CSOEconClaimCode', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONCLAIMCODE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconClaimCode)
  ))
_sym_db.RegisterMessage(CSOEconClaimCode)

CMsgUpdateItemSchema = _reflection.GeneratedProtocolMessageType('CMsgUpdateItemSchema', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPDATEITEMSCHEMA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgUpdateItemSchema)
  ))
_sym_db.RegisterMessage(CMsgUpdateItemSchema)

CMsgGCError = _reflection.GeneratedProtocolMessageType('CMsgGCError', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCERROR,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCError)
  ))
_sym_db.RegisterMessage(CMsgGCError)

CMsgRequestInventoryRefresh = _reflection.GeneratedProtocolMessageType('CMsgRequestInventoryRefresh', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTINVENTORYREFRESH,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRequestInventoryRefresh)
  ))
_sym_db.RegisterMessage(CMsgRequestInventoryRefresh)

CMsgConVarValue = _reflection.GeneratedProtocolMessageType('CMsgConVarValue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONVARVALUE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgConVarValue)
  ))
_sym_db.RegisterMessage(CMsgConVarValue)

CMsgReplicateConVars = _reflection.GeneratedProtocolMessageType('CMsgReplicateConVars', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREPLICATECONVARS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgReplicateConVars)
  ))
_sym_db.RegisterMessage(CMsgReplicateConVars)

CMsgItemAcknowledged = _reflection.GeneratedProtocolMessageType('CMsgItemAcknowledged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGITEMACKNOWLEDGED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgItemAcknowledged)
  ))
_sym_db.RegisterMessage(CMsgItemAcknowledged)

CMsgSetItemPositions = _reflection.GeneratedProtocolMessageType('CMsgSetItemPositions', (_message.Message,), dict(

  ItemPosition = _reflection.GeneratedProtocolMessageType('ItemPosition', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSETITEMPOSITIONS_ITEMPOSITION,
    __module__ = 'base_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSetItemPositions.ItemPosition)
    ))
  ,
  DESCRIPTOR = _CMSGSETITEMPOSITIONS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSetItemPositions)
  ))
_sym_db.RegisterMessage(CMsgSetItemPositions)
_sym_db.RegisterMessage(CMsgSetItemPositions.ItemPosition)

CMsgGCNameItemNotification = _reflection.GeneratedProtocolMessageType('CMsgGCNameItemNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNAMEITEMNOTIFICATION,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCNameItemNotification)
  ))
_sym_db.RegisterMessage(CMsgGCNameItemNotification)

CMsgGCClientDisplayNotification = _reflection.GeneratedProtocolMessageType('CMsgGCClientDisplayNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTDISPLAYNOTIFICATION,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCClientDisplayNotification)
  ))
_sym_db.RegisterMessage(CMsgGCClientDisplayNotification)

CMsgGCShowItemsPickedUp = _reflection.GeneratedProtocolMessageType('CMsgGCShowItemsPickedUp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSHOWITEMSPICKEDUP,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCShowItemsPickedUp)
  ))
_sym_db.RegisterMessage(CMsgGCShowItemsPickedUp)

CMsgGCIncrementKillCountResponse = _reflection.GeneratedProtocolMessageType('CMsgGCIncrementKillCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCINCREMENTKILLCOUNTRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCIncrementKillCountResponse)
  ))
_sym_db.RegisterMessage(CMsgGCIncrementKillCountResponse)

CSOEconItemDropRateBonus = _reflection.GeneratedProtocolMessageType('CSOEconItemDropRateBonus', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMDROPRATEBONUS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItemDropRateBonus)
  ))
_sym_db.RegisterMessage(CSOEconItemDropRateBonus)

CSOEconItemLeagueViewPass = _reflection.GeneratedProtocolMessageType('CSOEconItemLeagueViewPass', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMLEAGUEVIEWPASS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItemLeagueViewPass)
  ))
_sym_db.RegisterMessage(CSOEconItemLeagueViewPass)

CSOEconItemEventTicket = _reflection.GeneratedProtocolMessageType('CSOEconItemEventTicket', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMEVENTTICKET,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItemEventTicket)
  ))
_sym_db.RegisterMessage(CSOEconItemEventTicket)

CSOEconItemTournamentPassport = _reflection.GeneratedProtocolMessageType('CSOEconItemTournamentPassport', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMTOURNAMENTPASSPORT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CSOEconItemTournamentPassport)
  ))
_sym_db.RegisterMessage(CSOEconItemTournamentPassport)

CMsgGCStorePurchaseCancel = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseCancel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASECANCEL,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCStorePurchaseCancel)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseCancel)

CMsgGCStorePurchaseCancelResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseCancelResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASECANCELRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCStorePurchaseCancelResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseCancelResponse)

CMsgGCStorePurchaseFinalize = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseFinalize', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEFINALIZE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCStorePurchaseFinalize)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseFinalize)

CMsgGCStorePurchaseFinalizeResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseFinalizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEFINALIZERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCStorePurchaseFinalizeResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseFinalizeResponse)

CMsgGCToGCBannedWordListUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBannedWordListUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBANNEDWORDLISTUPDATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCBannedWordListUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBannedWordListUpdated)

CMsgGCToGCDirtySDOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDirtySDOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDIRTYSDOCACHE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCDirtySDOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDirtySDOCache)

CMsgGCToGCDirtyMultipleSDOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDirtyMultipleSDOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDIRTYMULTIPLESDOCACHE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCDirtyMultipleSDOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDirtyMultipleSDOCache)

CMsgGCToGCApplyLocalizationDiff = _reflection.GeneratedProtocolMessageType('CMsgGCToGCApplyLocalizationDiff', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCAPPLYLOCALIZATIONDIFF,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCApplyLocalizationDiff)
  ))
_sym_db.RegisterMessage(CMsgGCToGCApplyLocalizationDiff)

CMsgGCToGCApplyLocalizationDiffResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCApplyLocalizationDiffResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCAPPLYLOCALIZATIONDIFFRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCApplyLocalizationDiffResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCApplyLocalizationDiffResponse)

CMsgGCCollectItem = _reflection.GeneratedProtocolMessageType('CMsgGCCollectItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCOLLECTITEM,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCCollectItem)
  ))
_sym_db.RegisterMessage(CMsgGCCollectItem)

CMsgSDONoMemcached = _reflection.GeneratedProtocolMessageType('CMsgSDONoMemcached', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSDONOMEMCACHED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSDONoMemcached)
  ))
_sym_db.RegisterMessage(CMsgSDONoMemcached)

CMsgGCToGCUpdateSQLKeyValue = _reflection.GeneratedProtocolMessageType('CMsgGCToGCUpdateSQLKeyValue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCUPDATESQLKEYVALUE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCUpdateSQLKeyValue)
  ))
_sym_db.RegisterMessage(CMsgGCToGCUpdateSQLKeyValue)

CMsgGCServerVersionUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCServerVersionUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSERVERVERSIONUPDATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCServerVersionUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCServerVersionUpdated)

CMsgGCClientVersionUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCClientVersionUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTVERSIONUPDATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCClientVersionUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCClientVersionUpdated)

CMsgGCToGCWebAPIAccountChanged = _reflection.GeneratedProtocolMessageType('CMsgGCToGCWebAPIAccountChanged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCWEBAPIACCOUNTCHANGED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCWebAPIAccountChanged)
  ))
_sym_db.RegisterMessage(CMsgGCToGCWebAPIAccountChanged)

CMsgRecipeComponent = _reflection.GeneratedProtocolMessageType('CMsgRecipeComponent', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRECIPECOMPONENT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgRecipeComponent)
  ))
_sym_db.RegisterMessage(CMsgRecipeComponent)

CMsgFulfillDynamicRecipeComponent = _reflection.GeneratedProtocolMessageType('CMsgFulfillDynamicRecipeComponent', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFULFILLDYNAMICRECIPECOMPONENT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgFulfillDynamicRecipeComponent)
  ))
_sym_db.RegisterMessage(CMsgFulfillDynamicRecipeComponent)

CMsgGCClientMarketDataRequest = _reflection.GeneratedProtocolMessageType('CMsgGCClientMarketDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTMARKETDATAREQUEST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCClientMarketDataRequest)
  ))
_sym_db.RegisterMessage(CMsgGCClientMarketDataRequest)

CMsgGCClientMarketDataEntry = _reflection.GeneratedProtocolMessageType('CMsgGCClientMarketDataEntry', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTMARKETDATAENTRY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCClientMarketDataEntry)
  ))
_sym_db.RegisterMessage(CMsgGCClientMarketDataEntry)

CMsgGCClientMarketData = _reflection.GeneratedProtocolMessageType('CMsgGCClientMarketData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTMARKETDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCClientMarketData)
  ))
_sym_db.RegisterMessage(CMsgGCClientMarketData)

CMsgExtractGems = _reflection.GeneratedProtocolMessageType('CMsgExtractGems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGEXTRACTGEMS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgExtractGems)
  ))
_sym_db.RegisterMessage(CMsgExtractGems)

CMsgExtractGemsResponse = _reflection.GeneratedProtocolMessageType('CMsgExtractGemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGEXTRACTGEMSRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgExtractGemsResponse)
  ))
_sym_db.RegisterMessage(CMsgExtractGemsResponse)

CMsgAddSocket = _reflection.GeneratedProtocolMessageType('CMsgAddSocket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDSOCKET,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgAddSocket)
  ))
_sym_db.RegisterMessage(CMsgAddSocket)

CMsgAddSocketResponse = _reflection.GeneratedProtocolMessageType('CMsgAddSocketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDSOCKETRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgAddSocketResponse)
  ))
_sym_db.RegisterMessage(CMsgAddSocketResponse)

CMsgAddItemToSocketData = _reflection.GeneratedProtocolMessageType('CMsgAddItemToSocketData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDITEMTOSOCKETDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgAddItemToSocketData)
  ))
_sym_db.RegisterMessage(CMsgAddItemToSocketData)

CMsgAddItemToSocket = _reflection.GeneratedProtocolMessageType('CMsgAddItemToSocket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDITEMTOSOCKET,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgAddItemToSocket)
  ))
_sym_db.RegisterMessage(CMsgAddItemToSocket)

CMsgAddItemToSocketResponse = _reflection.GeneratedProtocolMessageType('CMsgAddItemToSocketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDITEMTOSOCKETRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgAddItemToSocketResponse)
  ))
_sym_db.RegisterMessage(CMsgAddItemToSocketResponse)

CMsgResetStrangeGemCount = _reflection.GeneratedProtocolMessageType('CMsgResetStrangeGemCount', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETSTRANGEGEMCOUNT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgResetStrangeGemCount)
  ))
_sym_db.RegisterMessage(CMsgResetStrangeGemCount)

CMsgResetStrangeGemCountResponse = _reflection.GeneratedProtocolMessageType('CMsgResetStrangeGemCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETSTRANGEGEMCOUNTRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgResetStrangeGemCountResponse)
  ))
_sym_db.RegisterMessage(CMsgResetStrangeGemCountResponse)

CMsgGCToClientPollFileRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPollFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPOLLFILEREQUEST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPollFileRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPollFileRequest)

CMsgGCToClientPollFileResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPollFileResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPOLLFILERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPollFileResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPollFileResponse)

CMsgGCToGCPerformManualOp = _reflection.GeneratedProtocolMessageType('CMsgGCToGCPerformManualOp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCPERFORMMANUALOP,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCPerformManualOp)
  ))
_sym_db.RegisterMessage(CMsgGCToGCPerformManualOp)

CMsgGCToGCPerformManualOpCompleted = _reflection.GeneratedProtocolMessageType('CMsgGCToGCPerformManualOpCompleted', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCPERFORMMANUALOPCOMPLETED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCPerformManualOpCompleted)
  ))
_sym_db.RegisterMessage(CMsgGCToGCPerformManualOpCompleted)

CMsgGCToGCReloadServerRegionSettings = _reflection.GeneratedProtocolMessageType('CMsgGCToGCReloadServerRegionSettings', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCRELOADSERVERREGIONSETTINGS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCReloadServerRegionSettings)
  ))
_sym_db.RegisterMessage(CMsgGCToGCReloadServerRegionSettings)


DESCRIPTOR._options = None
_CMSGCLIENTPINGDATA.fields_by_name['relay_codes']._options = None
_CMSGCLIENTPINGDATA.fields_by_name['relay_pings']._options = None
_CMSGCLIENTPINGDATA.fields_by_name['region_codes']._options = None
_CMSGCLIENTPINGDATA.fields_by_name['region_pings']._options = None
_CMSGGCINCREMENTKILLCOUNTRESPONSE.fields_by_name['killer_account_id']._options = None
_CSOECONITEMDROPRATEBONUS.fields_by_name['account_id']._options = None
_CSOECONITEMDROPRATEBONUS.fields_by_name['bonus']._options = None
_CSOECONITEMDROPRATEBONUS.fields_by_name['booster_type']._options = None
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['account_id']._options = None
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['league_id']._options = None
# @@protoc_insertion_point(module_scope)
